@@ -18,10 +18,12 @@ for opt in opts:
         mainProcess.outputHelpInfo()
     elif argKey == '--mode' or argKey == '-m':
         mode = argVal
-        if(mode == 'img_recove'):
+        if mode == 'img_recove':
             mainProcess.imgRecovery()
-        else:
+        elif mode=='normal':
             mainProcess.main()
+        else:
+            print("错误的mode参数")
     else:
         mainProcess.main()
     break
