@@ -148,7 +148,7 @@ class Main():
         print("所有markdown文档已处理完毕")
 
     def copyImgFromWeb(self, webImg, localImgPath):
-        if localImgPath[0:4] == 'http':
+        if localImgPath[0:4] == 'http' or webImg[0:4] != 'http':
             return
         if not os.path.exists(localImgPath):
             downloader = DownloadHelp()
